import pandas as pd

from my_model.config.core import config


def drop_na_inputs(*, input_data: pd.DataFrame) -> pd.DataFrame:
    """Check model inputs for na values and filter."""
    validated_data = input_data.copy()
    new_vars_with_na = [
        var
        for var in config.model_config.features
        if var not in config.model_config.numerical_vars_with_na
        and validated_data[var].isnull().sum() > 0
    ]
    validated_data.dropna(subset=new_vars_with_na, inplace=True)

    return validated_data



# PONER TODOS LOS IMPORTS AQUÍ:
from feature_engine.selection import DropFeatures
from feature_engine.wrappers import SklearnTransformerWrapper
from sklearn.linear_model import LogisticRegression
from sklearn.pipeline import Pipeline
from sklearn.preprocessing import StandardScaler

from my_model.config.core import config

numeric_transformer = StandardScaler()
preprocessor_num = SklearnTransformerWrapper(
    transformer=numeric_transformer, variables=config.model_config.num_features
)

LRwine = Pipeline(
    [
        (
            "preproc",
            preprocessor_num,
        ),
        (
            "drop_features",
            DropFeatures(features_to_drop=config.model_config.drop_features),
        ),
        ("LogisticR", LogisticRegression()),
    ]
)



import typing as t

import pandas as pd

from my_model import __version__ as _version
from my_model.config.core import config
from my_model.processing.data_manager import load_pipeline

pipeline_file_name = f"{config.app_config.pipeline_save_file}{_version}.pkl"
# nombre del pipe...se pone con _ , por ejemplo _genero_pipe
_wineLR = load_pipeline(file_name=pipeline_file_name)


def make_prediction(
    *,
    input_data: t.Union[pd.DataFrame, dict],
) -> dict:
    """Make a prediction using a saved model pipeline."""
    data = pd.DataFrame(input_data)
    results = {"predictions": None, "version": _version}

    predictions = _wineLR.predict(X=data[config.model_config.features])
    results = {
        "predictions": predictions,
        "version": _version,
    }

    return results
